@@ -1,5 +1,5 @@
 import time
-from viso_sdk.logging.status_logger import get_status_logger
+from viso_sdk.status import get_status_logger
 
 
 if __name__ == '__main__':
