@@ -26,7 +26,8 @@ from viso_sdk import (
     mqtt,
     nodered,
     redis,
-    visualize
+    visualize,
+    status
 )
 
 from viso_sdk._version import (  # noqa: F401
