@@ -1,4 +1,3 @@
-
 # =====================================================================================================================
 # architectures
 class ARCHITECTURE:
@@ -22,6 +21,7 @@ class FRAMEWORK:
     MmDetection = "mmdetection"
     MmDetection_GPU = "mmdetection_gpu"
     TensorRT = "tensorrt"
+    ONNX = "onnx"
     OTHER = "other"
 
 
@@ -74,6 +74,10 @@ class DEVICE:
         CPU = "CPU"
         CUDA = "CUDA"
 
+    class ONNX:
+        CPU = "CPU"
+        CUDA = "CUDA"
+
 
 # =====================================================================================================================
 SUPPORT_DEVICES = {
@@ -90,9 +94,19 @@ SUPPORT_DEVICES = {
         FRAMEWORK.FURIOSA: [DEVICE.FURIOSA.CPU, DEVICE.FURIOSA.CUDA],
         FRAMEWORK.MmDetection: [DEVICE.MmDetection.CPU],
         FRAMEWORK.MmDetection_GPU: [DEVICE.MmDetection.CPU, DEVICE.MmDetection_GPU.CUDA],
+        FRAMEWORK.TensorRT: [DEVICE.TensorRT.CPU, DEVICE.TensorRT.CUDA],
+        FRAMEWORK.ONNX: [DEVICE.ONNX.CPU, DEVICE.ONNX.CUDA],
+    },
+    ARCHITECTURE.AARCH64: {
+        FRAMEWORK.TF: [DEVICE.TF.CPU],
+        FRAMEWORK.TF_LITE: [DEVICE.TF_LITE.CPU, DEVICE.TF_LITE.eTPU],
+        FRAMEWORK.TORCH: [DEVICE.TORCH.CPU],
+        FRAMEWORK.TORCH_GPU: [DEVICE.TORCH.CPU, DEVICE.TORCH.CUDA],
+        FRAMEWORK.OPENVINO: [DEVICE.OPENVINO.CPU],  # OpenVINO for ARM64 is CPU only
+        FRAMEWORK.MmDetection: [DEVICE.MmDetection.CPU],
+        FRAMEWORK.MmDetection_GPU: [DEVICE.MmDetection.CPU, DEVICE.MmDetection_GPU.CUDA],
         FRAMEWORK.TensorRT: [DEVICE.TensorRT.CPU, DEVICE.TensorRT.CUDA]
     },
-    ARCHITECTURE.AARCH64: {},
     ARCHITECTURE.ARMV7HF: {}
 }
 
@@ -110,6 +124,7 @@ class MODEL_TYPE:
     KERAS = "KERAS"
     CAFFE = "CAFFE"
     TensorRT = "TensorRT"
+    OTHER = "other"
 
 
 # =====================================================================================================================
@@ -138,7 +153,6 @@ class KEY:
 
 # ----- [MQTT & REDIS] ----------------------------------------------------------
 class PREFIX:
-
     class REDIS:
         LOCAL = "redis"
         STATUS = "viso/container_status"
@@ -158,3 +172,23 @@ AVAILABLE_METADATA_MODES = ["mqtt", "redis"]
 class MetaDataMODE:
     MQTT = "mqtt"
     REDIS = "redis"
+
+
+# =====================================================================================================================
+# publish object keys
+class PublishData:
+    ROI = "roi"
+    TRACK = "track"
+    COUNT = "count"
+    SAVE_PATH = "save_path"
+    DETECT = "result"
+    TIME_STAMP = "timestamp"
+    FRAME_ID = "frame_id"
+    REFERENCE_POINT = "ref_pos"
+    OCR = "ocr"
+    BARCODE = "barcode"
+    CROWD = "crowd"
+    CROWD_POINTS = "crowd_points"
+    CHANGED_OBJS = "changed_objs"
+    ANALYTICS = "analytics"
+    ANALYTICS_ROI = "analytics_roi"
