@@ -104,7 +104,7 @@ class RedisWrapper:
         Args:
             redis_key(str): Target redis key.
         """
-        return self._redis_client.get(redis_key)
+        return self._redis_client.getdel(redis_key)
 
     def read_viso_data(
             self,
