@@ -79,7 +79,7 @@ def get_rgba_color(color=None):
 
 def get_rgba_color_with_palette_id(palette_id):
     if palette_id is not None:
-        color = PALETTE[palette_id]
+        color = PALETTE[palette_id % 256]
         return tuple([color[2], color[1], color[0], DEFAULT_OPACITY])
     else:
         return None
